from a10sdk.common.A10BaseClass import A10BaseClass


class Interface(A10BaseClass):
    
    """Class Description::
    Select an interface to configure.

    Class interface supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param tunnel_list: {"minItems": 1, "items": {"type": "tunnel"}, "uniqueItems": true, "array": [{"required": ["ifnum"], "properties": {"ip": {"type": "object", "properties": {"generate-membership-query": {"default": 0, "type": "number", "description": "Enable Membership Query", "format": "flag"}, "max-resp-time": {"description": "Max Response Time (Default is 100)", "format": "number", "default": 100, "maximum": 255, "minimum": 1, "type": "number"}, "generate-membership-query-val": {"description": "1 - 255 (Default is 125)", "format": "number", "default": 125, "maximum": 255, "minimum": 1, "type": "number"}, "address": {"type": "object", "properties": {"ip-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv4-address": {"type": "string", "description": "IP address", "format": "ipv4-address"}, "optional": true, "ipv4-netmask": {"type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}}}]}, "dhcp": {"default": 0, "type": "number", "description": "Use DHCP to configure IP address", "format": "flag"}}}}}, "ifnum": {"description": "Tunnel interface number", "format": "number", "type": "number", "maximum": 128, "minimum": 1, "optional": false}, "ipv6": {"type": "object", "properties": {"address-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"link-local": {"default": 0, "type": "number", "description": "Configure an IPv6 link local address", "format": "flag"}, "anycast": {"default": 0, "type": "number", "description": "Configure an IPv6 anycast address", "format": "flag"}, "ipv6-addr": {"type": "string", "description": "Set the IPv6 address of an interface", "format": "ipv6-address-plen"}, "optional": true}}]}, "ipv6-enable": {"default": 0, "type": "number", "description": "Enable IPv6 processing", "format": "flag"}}}}}], "type": "array", "$ref": "/axapi/v3/interface/tunnel/{ifnum}"}
    :param trunk_list: {"minItems": 1, "items": {"type": "trunk"}, "uniqueItems": true, "array": [{"required": ["ifnum"], "properties": {"icmp-rate-limit": {"type": "object", "properties": {"lockup": {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "lockup-period": {"description": "Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period", "minimum": 1, "type": "number", "maximum": 16383, "format": "number"}, "normal": {"description": "Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}, "isis": {"type": "object", "properties": {"priority-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Set priority for Designated Router election (Priority value)", "format": "number", "default": 64, "maximum": 127, "minimum": 0, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify priority for level-1 routing; 'level-2': Specify priority for level-2 routing; ", "format": "enum"}}}]}, "hello-interval-minimal-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"hello-interval-minimal": {"default": 0, "type": "number", "description": "Set Hello holdtime 1 second, interval depends on multiplier", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}}}]}, "mesh-group": {"type": "object", "properties": {"value": {"description": "Mesh group number", "format": "number", "maximum": 4294967295, "minimum": 1, "not": "blocked", "type": "number"}, "blocked": {"default": 0, "not": "value", "type": "number", "description": "Block LSPs on this interface", "format": "flag"}}}, "network": {"enum": ["broadcast", "point-to-point"], "type": "string", "description": "'broadcast': Specify IS-IS broadcast multi-access network; 'point-to-point': Specify IS-IS point-to-point network; ", "format": "enum"}, "bfd-cfg": {"type": "object", "properties": {"disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}}}, "csnp-interval-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Speficy interval for level-1 CSNPs; 'level-2': Specify interval for level-2 CSNPs; ", "format": "enum"}, "optional": true, "csnp-interval": {"description": "Set CSNP interval in seconds (CSNP interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}}}]}, "retransmit-interval": {"description": "Set per-LSP retransmission interval (Interval between retransmissions of the same LSP (seconds))", "format": "number", "default": 5, "maximum": 65535, "minimum": 0, "type": "number"}, "password-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"password": {"minLength": 1, "maxLength": 254, "type": "string", "description": "Configure the authentication password for interface", "format": "string-rlx"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify password for level-1 PDUs; 'level-2': Specify password for level-2 PDUs; ", "format": "enum"}}}]}, "authentication": {"type": "object", "properties": {"key-chain-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"key-chain": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication key-chain for level-1 PDUs; 'level-2': Specify authentication key-chain for level-2 PDUs; ", "format": "enum"}}}]}, "mode-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "mode": {"enum": ["md5"], "type": "string", "description": "'md5': Keyed message digest; ", "format": "enum"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication mode for level-1 PDUs; 'level-2': Specify authentication mode for level-2 PDUs; ", "format": "enum"}}}]}, "send-only-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"send-only": {"default": 0, "type": "number", "description": "Authentication send-only", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication send-only for level-1 PDUs; 'level-2': Specify authentication send-only for level-2 PDUs; ", "format": "enum"}}}]}}}, "wide-metric-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "wide-metric": {"description": "Configure the wide metric for interface", "format": "number", "default": 10, "maximum": 16777214, "minimum": 1, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}}}]}, "hello-interval-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-interval": {"description": "Set Hello interval in seconds (Hello interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}}}]}, "lsp-interval": {"description": "Set LSP transmission interval (LSP transmission interval (milliseconds))", "format": "number", "default": 33, "maximum": 4294967295, "minimum": 1, "type": "number"}, "circuit-type": {"default": "level-1-2", "enum": ["level-1", "level-1-2", "level-2-only"], "type": "string", "description": "'level-1': Level-1 only adjacencies are formed; 'level-1-2': Level-1-2 adjacencies are formed; 'level-2-only': Level-2 only adjacencies are formed; ", "format": "enum"}, "hello-multiplier-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-multiplier": {"description": "Set multiplier for Hello holding time (Hello multiplier value)", "format": "number", "default": 3, "maximum": 100, "minimum": 2, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello multiplier for level-1 IIHs; 'level-2': Specify hello multiplier for level-2 IIHs; ", "format": "enum"}}}]}, "metric-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"metric": {"description": "Configure the metric for interface (Default metric)", "format": "number", "default": 10, "maximum": 63, "minimum": 1, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}}}]}, "hello": {"enum": ["padding"], "type": "string", "description": "'padding': Pad hello packets; ", "format": "enum"}}}, "name": {"description": "Name for the interface", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 32, "type": "string"}, "trap-source": {"default": 0, "optional": true, "type": "number", "description": "The trap source", "format": "flag"}, "bfd": {"type": "object", "properties": {"authentication": {"type": "object", "properties": {"encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "password": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Key String", "format": "password"}, "method": {"enum": ["md5", "meticulous-md5", "meticulous-sha1", "sha1", "simple"], "type": "string", "description": "'md5': Keyed MD5; 'meticulous-md5': Meticulous Keyed MD5; 'meticulous-sha1': Meticulous Keyed SHA1; 'sha1': Keyed SHA1; 'simple': Simple Password; ", "format": "enum"}, "key-id": {"description": "Key ID", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}}}, "demand": {"default": 0, "type": "number", "description": "Demand mode", "format": "flag"}, "interval-cfg": {"type": "object", "properties": {"interval": {"description": "Transmit interval between BFD packets (Milliseconds)", "minimum": 48, "type": "number", "maximum": 1000, "format": "number"}, "min-rx": {"description": "Minimum receive interval capability (Milliseconds)", "minimum": 48, "type": "number", "maximum": 1000, "format": "number"}, "multiplier": {"description": "Multiplier value used to compute holddown (value used to multiply the interval)", "minimum": 3, "type": "number", "maximum": 50, "format": "number"}}}, "echo": {"default": 0, "type": "number", "description": "Enable BFD Echo", "format": "flag"}}}, "ip": {"type": "object", "properties": {"generate-membership-query": {"default": 0, "type": "number", "description": "Enable Membership Query", "format": "flag"}, "cache-spoofing-port": {"default": 0, "type": "number", "description": "This interface connects to spoofing cache", "format": "flag"}, "router": {"type": "object", "properties": {"isis": {"type": "object", "properties": {"tag": {"description": "ISO routing area tag", "format": "string", "minLength": 1, "modify-not-allowed": 1, "maxLength": 128, "type": "string"}}}}}, "allow-promiscuous-vip": {"default": 0, "type": "number", "description": "Allow traffic to be associated with promiscuous VIP", "format": "flag"}, "max-resp-time": {"description": "Maximum Response Time (Max Response Time (Default is 100))", "format": "number", "default": 100, "maximum": 255, "minimum": 1, "type": "number"}, "query-interval": {"description": "1 - 255 (Default is 125)", "format": "number", "default": 125, "maximum": 255, "minimum": 1, "type": "number"}, "helper-address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"helper-address": {"type": "string", "description": "Helper address for DHCP packets (IP address)", "format": "ipv4-address"}, "optional": true}}]}, "stateful-firewall": {"type": "object", "properties": {"access-list": {"default": 0, "type": "number", "description": "Access-list for traffic from the outside", "format": "flag"}, "inside": {"default": 0, "type": "number", "description": "Inside (private) interface for stateful firewall", "format": "flag"}, "acl-id": {"description": "ACL id", "minimum": 1, "type": "number", "maximum": 199, "format": "number"}, "outside": {"default": 0, "type": "number", "description": "Outside (public) interface for stateful firewall", "format": "flag"}}}, "rip": {"type": "object", "properties": {"receive-cfg": {"type": "object", "properties": {"receive": {"default": 0, "type": "number", "description": "Advertisement reception", "format": "flag"}, "version": {"enum": ["1", "2", "1-2"], "type": "string", "description": "'1': RIP version 1; '2': RIP version 2; '1-2': RIP version 1 & 2; ", "format": "enum"}}}, "receive-packet": {"default": 1, "type": "number", "description": "Enable receiving packet through the specified interface", "format": "flag"}, "split-horizon-cfg": {"type": "object", "properties": {"state": {"default": "poisoned", "enum": ["poisoned", "disable", "enable"], "type": "string", "description": "'poisoned': Perform split horizon with poisoned reverse; 'disable': Disable split horizon; 'enable': Perform split horizon without poisoned reverse; ", "format": "enum"}}}, "authentication": {"type": "object", "properties": {"key-chain": {"type": "object", "properties": {"key-chain": {"type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string-rlx"}}}, "mode": {"type": "object", "properties": {"mode": {"default": "text", "enum": ["md5", "text"], "type": "string", "description": "'md5': Keyed message digest; 'text': Clear text authentication; ", "format": "enum"}}}, "str": {"type": "object", "properties": {"string": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The RIP authentication string", "format": "string-rlx"}}}}}, "send-cfg": {"type": "object", "properties": {"version": {"enum": ["1", "2", "1-compatible", "1-2"], "type": "string", "description": "'1': RIP version 1; '2': RIP version 2; '1-compatible': RIPv1-compatible; '1-2': RIP version 1 & 2; ", "format": "enum"}, "send": {"default": 0, "type": "number", "description": "Advertisement transmission", "format": "flag"}}}, "send-packet": {"default": 1, "type": "number", "description": "Enable sending packets through the specified interface", "format": "flag"}}}, "nat": {"type": "object", "properties": {"inside": {"default": 0, "type": "number", "description": "Configure interface as inside", "format": "flag"}, "outside": {"default": 0, "type": "number", "description": "Configure interface as outside", "format": "flag"}}}, "address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv4-address": {"type": "string", "description": "IP address", "format": "ipv4-address"}, "optional": true, "ipv4-netmask": {"type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}}}]}, "dhcp": {"default": 0, "type": "number", "description": "Use DHCP to configure IP address", "format": "flag"}, "ospf": {"type": "object", "properties": {"ospf-ip-list": {"minItems": 1, "items": {"type": "ospf-ip"}, "uniqueItems": true, "array": [{"required": ["ip-addr"], "properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication-key": {"description": "Authentication password (key) (The OSPF password (key))", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 8, "type": "string"}, "mtu-ignore": {"default": 0, "optional": true, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "priority": {"description": "Router priority", "format": "number", "default": 1, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "value": {"optional": true, "enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use no authentication; ", "format": "enum"}, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication": {"default": 0, "optional": true, "type": "number", "description": "Enable authentication", "format": "flag"}, "cost": {"description": "Interface cost", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "database-filter": {"optional": true, "enum": ["all"], "type": "string", "description": "'all': Filter all LSA; ", "format": "enum"}, "ip-addr": {"optional": false, "type": "string", "description": "Address of interface", "format": "ipv4-address"}, "retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "message-digest-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"md5-value": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}, "message-digest-key": {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}]}, "out": {"default": 0, "optional": true, "type": "number", "description": "Outgoing LSA", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/interface/trunk/{ifnum}/ip/ospf/ospf-ip/{ip-addr}"}, "ospf-global": {"type": "object", "properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication-key": {"minLength": 1, "maxLength": 8, "type": "string", "description": "Authentication password (key) (The OSPF password (key))", "format": "string-rlx"}, "network": {"type": "object", "properties": {"broadcast": {"default": 0, "not-list": ["non-broadcast", "point-to-point", "point-to-multipoint"], "type": "number", "description": "Specify OSPF broadcast multi-access network", "format": "flag"}, "point-to-multipoint": {"default": 0, "not-list": ["broadcast", "non-broadcast", "point-to-point"], "type": "number", "description": "Specify OSPF point-to-multipoint network", "format": "flag"}, "non-broadcast": {"default": 0, "not-list": ["broadcast", "point-to-point", "point-to-multipoint"], "type": "number", "description": "Specify OSPF NBMA network", "format": "flag"}, "point-to-point": {"default": 0, "not-list": ["broadcast", "non-broadcast", "point-to-multipoint"], "type": "number", "description": "Specify OSPF point-to-point network", "format": "flag"}, "p2mp-nbma": {"default": 0, "type": "number", "description": "Specify non-broadcast point-to-multipoint network", "format": "flag"}}}, "mtu-ignore": {"default": 0, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "maximum": 65535, "minimum": 1, "type": "number"}, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "disable": {"enum": ["all"], "type": "string", "description": "'all': All functionality; ", "format": "enum"}, "authentication-cfg": {"type": "object", "properties": {"authentication": {"default": 0, "type": "number", "description": "Enable authentication", "format": "flag"}, "value": {"enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use no authentication; ", "format": "enum"}}}, "database-filter-cfg": {"type": "object", "properties": {"database-filter": {"enum": ["all"], "type": "string", "description": "'all': Filter all LSA; ", "format": "enum"}, "out": {"default": 0, "type": "number", "description": "Outgoing LSA", "format": "flag"}}}, "bfd-cfg": {"type": "object", "properties": {"disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}}}, "cost": {"description": "Interface cost", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "mtu": {"description": "OSPF interface MTU (MTU size)", "minimum": 576, "type": "number", "maximum": 65535, "format": "number"}, "message-digest-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"message-digest-key": {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "md5": {"type": "object", "properties": {"md5-value": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}, "encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}}}]}, "priority": {"description": "Router priority", "format": "number", "default": 1, "maximum": 255, "minimum": 0, "type": "number"}}}}}, "slb-partition-redirect": {"default": 0, "type": "number", "description": "Redirect SLB traffic across partition", "format": "flag"}}}, "access-list": {"type": "object", "properties": {"acl-name": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Apply an access list (Named Access List)", "format": "string"}, "acl-id": {"description": "ACL id", "format": "number", "maximum": 199, "$ref-list": ["/axapi/v3/access-list/standard", "/axapi/v3/access-list/extended"], "minimum": 1, "type": "number"}}}, "icmpv6-rate-limit": {"type": "object", "properties": {"lockup-period-v6": {"description": "Lockup period (second)", "minimum": 1, "type": "number", "maximum": 16383, "format": "number"}, "normal-v6": {"description": "Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "lockup-v6": {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}, "timer": {"description": "Timer to re-check the threshold under certain conditions (Time in seconds (Default: 10))", "format": "number", "default": 10, "optional": true, "maximum": 300, "minimum": 1, "type": "number"}, "mtu": {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Interface mtu (Interface MTU, default 1500 (min MTU is 1280 for IPv6))", "format": "number", "optional": true, "type": "number"}, "ports-threshold": {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Threshold for the minimum number of ports that need to be UP for the trunk to remain UP", "format": "number", "optional": true, "type": "number"}, "ifnum": {"optional": false, "type": "number", "description": "Trunk interface number", "format": "number"}, "do-auto-recovery": {"default": 0, "optional": true, "type": "number", "description": "(Only for LACP trunks) Attempt auto-recovery after ports-treshold is triggered", "format": "flag"}, "ipv6": {"type": "object", "properties": {"address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"address-type": {"enum": ["anycast", "link-local"], "type": "string", "description": "'anycast': Configure an IPv6 anycast address; 'link-local': Configure an IPv6 link local address; ", "format": "enum"}, "ipv6-addr": {"type": "string", "description": "Set the IPv6 address of an interface", "format": "ipv6-address-plen"}, "optional": true}}]}, "router-adver": {"type": "object", "properties": {"max-interval": {"description": "Set Router Advertisement Max Interval (default: 600) (Min Router Advertisement Interval (seconds))", "format": "number", "default": 600, "maximum": 1800, "minimum": 4, "type": "number"}, "default-lifetime": {"description": "Set Router Advertisement Default Lifetime (default: 1800) (Default Lifetime (seconds))", "format": "number", "default": 1800, "maximum": 9000, "minimum": 0, "type": "number"}, "reachable-time": {"description": "Set Router Advertisement Reachable ime (default: 0) (Reachable Time (milliseconds))", "format": "number", "default": 0, "maximum": 3600000, "minimum": 0, "type": "number"}, "vrid": {"type": "object", "properties": {"floating-ip": {"type": "string", "description": "Use a floating IP as the source address for Router advertisements", "format": "ipv6-address"}, "adver-vrid-default": {"default": 0, "not": "adver-vrid", "type": "number", "description": "Default VRRP-A vrid", "format": "flag"}, "adver-vrid": {"description": "Specify ha VRRP-A vrid", "format": "number", "maximum": 31, "minimum": 1, "not": "adver-vrid-default", "type": "number"}, "use-floating-ip": {"default": 0, "type": "number", "description": "Use a floating IP as the source address for Router advertisements", "format": "flag"}}}, "prefix-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"not-autonomous": {"default": 0, "type": "number", "description": "Specify that the Prefix is not usable for autoconfiguration (default:autonomous)", "format": "flag"}, "valid-lifetime": {"description": "Specify Valid Lifetime (default:2592000) (Prefix Advertised Valid Lifetime (default: 2592000))", "format": "number", "default": 2592000, "maximum": 4294967295, "minimum": 0, "type": "number"}, "not-on-link": {"default": 0, "type": "number", "description": "Specify that the Prefix is not On-Link (default: on-link)", "format": "flag"}, "prefix": {"type": "string", "description": "Set Router Advertisement On-Link Prefix (IPv6 On-Link Prefix)", "format": "ipv6-address-plen"}, "preferred-lifetime": {"description": "Specify Prefix Preferred Lifetime (default:604800) (Prefix Advertised Preferred Lifetime (default: 604800))", "format": "number", "default": 604800, "maximum": 4294967295, "minimum": 0, "type": "number"}, "optional": true}}]}, "rate-limit": {"description": "Rate Limit the processing of incoming Router Solicitations (Max Number of Router Solicitations to process per second)", "format": "number", "default": 100000, "maximum": 100000, "minimum": 1, "type": "number"}, "mtu": {"type": "object", "properties": {"adver-mtu": {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Set Router Advertisement MTU Option", "format": "number", "not": "adver-mtu-disable", "type": "number"}, "adver-mtu-disable": {"default": 0, "not": "adver-mtu", "type": "number", "description": "Disable Router Advertisement MTU Option", "format": "flag"}}}, "min-interval": {"description": "Set Router Advertisement Min Interval (default: 200) (Max Number of Router Solicitations to process per second)", "format": "number", "default": 200, "maximum": 1350, "minimum": 3, "type": "number"}, "action": {"default": "enable", "enum": ["enable", "disable"], "type": "string", "description": "'enable': Enable Router Advertisements on this interface; 'disable': Disable Router Advertisements on this interface; ", "format": "enum"}, "retransmit-timer": {"description": "Set Router Advertisement Retransmit Timer (default: 0)", "format": "number", "default": 0, "maximum": 4294967295, "minimum": 0, "type": "number"}, "ha-group-id": {"type": "object", "properties": {"ha-use-floating-ip": {"default": 0, "type": "number", "description": "Use a floating IP as the source address for Router advertisements", "format": "flag"}, "adver-ha-group-id": {"description": "HA Group ID", "minimum": 1, "type": "number", "maximum": 31, "format": "number"}, "ha-floating-ip": {"type": "string", "description": "Use a floating IP as the source address for Router advertisements", "format": "ipv6-address"}}}, "hop-limit": {"description": "Set Router Advertisement Hop Limit (default: 255) (Max Router Advertisement Interval (seconds))", "format": "number", "default": 255, "maximum": 255, "minimum": 0, "type": "number"}}}, "rip": {"type": "object", "properties": {"split-horizon-cfg": {"type": "object", "properties": {"state": {"default": "poisoned", "enum": ["poisoned", "disable", "enable"], "type": "string", "description": "'poisoned': Perform split horizon with poisoned reverse; 'disable': Disable split horizon; 'enable': Perform split horizon without poisoned reverse; ", "format": "enum"}}}}}, "ipv6-enable": {"default": 0, "type": "number", "description": "Enable IPv6 processing", "format": "flag"}, "stateful-firewall": {"type": "object", "properties": {"access-list": {"default": 0, "type": "number", "description": "Access-list for traffic from the outside", "format": "flag"}, "acl-name": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Access-list Name", "format": "string"}, "inside": {"default": 0, "type": "number", "description": "Inside (private) interface for stateful firewall", "format": "flag"}, "outside": {"default": 0, "type": "number", "description": "Outside (public) interface for stateful firewall", "format": "flag"}}}, "nat": {"type": "object", "properties": {"inside": {"default": 0, "type": "number", "description": "Configure interface as NAT inside", "format": "flag"}, "outside": {"default": 0, "type": "number", "description": "Configure interface as NAT outside", "format": "flag"}}}, "router": {"type": "object", "properties": {"ripng": {"type": "object", "properties": {"rip": {"default": 0, "type": "number", "description": "RIP Routing for IPv6", "format": "flag"}}}, "ospf": {"type": "object", "properties": {"area-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"area-id-addr": {"type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}, "tag": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Set the OSPFv3 process tag", "format": "string"}, "optional": true, "instance-id": {"description": "Set the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}, "area-id-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}}}]}}}, "isis": {"type": "object", "properties": {"tag": {"description": "ISO routing area tag", "format": "string", "minLength": 1, "modify-not-allowed": 1, "maxLength": 128, "type": "string"}}}}}, "access-list-cfg": {"type": "object", "properties": {"inbound": {"default": 0, "type": "number", "description": "ACL applied on incoming packets to this interface", "format": "flag"}, "v6-acl-name": {"description": "Apply ACL rules to incoming packets on this interface (Named Access List)", "format": "string", "minLength": 1, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ipv6/access-list"}}}, "ospf": {"type": "object", "properties": {"bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "cost-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cost": {"description": "Interface cost", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "hello-interval-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "priority-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Router priority", "format": "number", "default": 1, "maximum": 255, "minimum": 0, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "mtu-ignore-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"mtu-ignore": {"default": 0, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "retransmit-interval-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "maximum": 65535, "minimum": 1, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "network-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"broadcast-type": {"enum": ["broadcast", "non-broadcast", "point-to-point", "point-to-multipoint"], "type": "string", "description": "'broadcast': Specify OSPF broadcast multi-access network; 'non-broadcast': Specify OSPF NBMA network; 'point-to-point': Specify OSPF point-to-point network; 'point-to-multipoint': Specify OSPF point-to-multipoint network; ", "format": "enum"}, "optional": true, "p2mp-nbma": {"default": 0, "type": "number", "description": "Specify non-broadcast point-to-multipoint network", "format": "flag"}, "network-instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "transmit-delay-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "neighbor-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"neighbor-priority": {"description": "OSPF priority of non-broadcast neighbor", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}, "neig-inst": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}, "neighbor-poll-interval": {"description": "OSPF dead-router polling interval (Seconds)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "neighbor-cost": {"description": "OSPF cost for point-to-multipoint neighbor (metric)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "neighbor": {"default": "::", "type": "string", "description": "OSPFv3 neighbor (Neighbor IPv6 address)", "format": "ipv6-address"}, "optional": true}}]}, "dead-interval-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "maximum": 65535, "minimum": 1, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}}}}}, "action": {"optional": true, "enum": ["enable", "disable"], "type": "string", "description": "'enable': Enable; 'disable': Disable; ", "format": "enum"}, "l3-vlan-fwd-disable": {"default": 0, "optional": true, "type": "number", "description": "Disable L3 forwarding between VLANs", "format": "flag"}, "ddos": {"type": "object", "properties": {"outside": {"default": 0, "type": "number", "description": "DDoS inside (trusted) or outside (untrusted) interface", "format": "flag"}, "inside": {"default": 0, "type": "number", "description": "DDoS inside (trusted) or outside (untrusted) interface", "format": "flag"}}}, "lw-4o6": {"type": "object", "properties": {"outside": {"default": 0, "type": "number", "description": "Configure LW-4over6 inside interface", "format": "flag"}, "inside": {"default": 0, "type": "number", "description": "Configure LW-4over6 outside interface", "format": "flag"}}}}}], "type": "array", "$ref": "/axapi/v3/interface/trunk/{ifnum}"}
    :param ve_list: {"minItems": 1, "items": {"type": "ve"}, "uniqueItems": true, "array": [{"required": ["ifnum"], "properties": {"icmp-rate-limit": {"type": "object", "properties": {"lockup": {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "lockup-period": {"description": "Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period", "minimum": 1, "type": "number", "maximum": 16383, "format": "number"}, "normal": {"description": "Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}, "isis": {"type": "object", "properties": {"priority-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Set priority for Designated Router election (Priority value)", "format": "number", "default": 64, "maximum": 127, "minimum": 0, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify priority for level-1 routing; 'level-2': Specify priority for level-2 routing; ", "format": "enum"}}}]}, "hello-interval-minimal-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"hello-interval-minimal": {"default": 0, "type": "number", "description": "Set Hello holdtime 1 second, interval depends on multiplier", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}}}]}, "mesh-group": {"type": "object", "properties": {"value": {"description": "Mesh group number", "format": "number", "maximum": 4294967295, "minimum": 1, "not": "blocked", "type": "number"}, "blocked": {"default": 0, "not": "value", "type": "number", "description": "Block LSPs on this interface", "format": "flag"}}}, "network": {"enum": ["broadcast", "point-to-point"], "type": "string", "description": "'broadcast': Specify IS-IS broadcast multi-access network; 'point-to-point': Specify IS-IS point-to-point network; ", "format": "enum"}, "bfd-cfg": {"type": "object", "properties": {"disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}}}, "csnp-interval-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Speficy interval for level-1 CSNPs; 'level-2': Specify interval for level-2 CSNPs; ", "format": "enum"}, "optional": true, "csnp-interval": {"description": "Set CSNP interval in seconds (CSNP interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}}}]}, "retransmit-interval": {"description": "Set per-LSP retransmission interval (Interval between retransmissions of the same LSP (seconds))", "format": "number", "default": 5, "maximum": 65535, "minimum": 0, "type": "number"}, "password-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"password": {"minLength": 1, "maxLength": 254, "type": "string", "description": "Configure the authentication password for interface", "format": "string-rlx"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify password for level-1 PDUs; 'level-2': Specify password for level-2 PDUs; ", "format": "enum"}}}]}, "authentication": {"type": "object", "properties": {"key-chain-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"key-chain": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication key-chain for level-1 PDUs; 'level-2': Specify authentication key-chain for level-2 PDUs; ", "format": "enum"}}}]}, "mode-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "mode": {"enum": ["md5"], "type": "string", "description": "'md5': Keyed message digest; ", "format": "enum"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication mode for level-1 PDUs; 'level-2': Specify authentication mode for level-2 PDUs; ", "format": "enum"}}}]}, "send-only-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"send-only": {"default": 0, "type": "number", "description": "Authentication send-only", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication send-only for level-1 PDUs; 'level-2': Specify authentication send-only for level-2 PDUs; ", "format": "enum"}}}]}}}, "wide-metric-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "wide-metric": {"description": "Configure the wide metric for interface", "format": "number", "default": 10, "maximum": 16777214, "minimum": 1, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}}}]}, "hello-interval-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-interval": {"description": "Set Hello interval in seconds (Hello interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}}}]}, "lsp-interval": {"description": "Set LSP transmission interval (LSP transmission interval (milliseconds))", "format": "number", "default": 33, "maximum": 4294967295, "minimum": 1, "type": "number"}, "circuit-type": {"default": "level-1-2", "enum": ["level-1", "level-1-2", "level-2-only"], "type": "string", "description": "'level-1': Level-1 only adjacencies are formed; 'level-1-2': Level-1-2 adjacencies are formed; 'level-2-only': Level-2 only adjacencies are formed; ", "format": "enum"}, "hello-multiplier-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-multiplier": {"description": "Set multiplier for Hello holding time (Hello multiplier value)", "format": "number", "default": 3, "maximum": 100, "minimum": 2, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello multiplier for level-1 IIHs; 'level-2': Specify hello multiplier for level-2 IIHs; ", "format": "enum"}}}]}, "metric-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"metric": {"description": "Configure the metric for interface (Default metric)", "format": "number", "default": 10, "maximum": 63, "minimum": 1, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}}}]}, "hello": {"enum": ["padding"], "type": "string", "description": "'padding': Pad hello packets; ", "format": "enum"}}}, "name": {"description": "Name for the interface", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 32, "type": "string"}, "trap-source": {"default": 0, "optional": true, "type": "number", "description": "The trap source", "format": "flag"}, "bfd": {"type": "object", "properties": {"authentication": {"type": "object", "properties": {"encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "password": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Key String", "format": "password"}, "method": {"enum": ["md5", "meticulous-md5", "meticulous-sha1", "sha1", "simple"], "type": "string", "description": "'md5': Keyed MD5; 'meticulous-md5': Meticulous Keyed MD5; 'meticulous-sha1': Meticulous Keyed SHA1; 'sha1': Keyed SHA1; 'simple': Simple Password; ", "format": "enum"}, "key-id": {"description": "Key ID", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}}}, "demand": {"default": 0, "type": "number", "description": "Demand mode", "format": "flag"}, "interval-cfg": {"type": "object", "properties": {"interval": {"description": "Transmit interval between BFD packets (Milliseconds)", "minimum": 48, "type": "number", "maximum": 1000, "format": "number"}, "min-rx": {"description": "Minimum receive interval capability (Milliseconds)", "minimum": 48, "type": "number", "maximum": 1000, "format": "number"}, "multiplier": {"description": "Multiplier value used to compute holddown (value used to multiply the interval)", "minimum": 3, "type": "number", "maximum": 50, "format": "number"}}}, "echo": {"default": 0, "type": "number", "description": "Enable BFD Echo", "format": "flag"}}}, "ip": {"type": "object", "properties": {"generate-membership-query": {"default": 0, "type": "number", "description": "Enable Membership Query", "format": "flag"}, "address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv4-address": {"type": "string", "description": "IP address", "format": "ipv4-address"}, "optional": true, "ipv4-netmask": {"type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}}}]}, "inside": {"default": 0, "type": "number", "description": "Configure interface as inside", "format": "flag"}, "allow-promiscuous-vip": {"default": 0, "type": "number", "description": "Allow traffic to be associated with promiscuous VIP", "format": "flag"}, "max-resp-time": {"description": "Maximum Response Time (Max Response Time (Default is 100))", "format": "number", "default": 100, "maximum": 255, "minimum": 1, "type": "number"}, "query-interval": {"description": "1 - 255 (Default is 125)", "format": "number", "default": 125, "maximum": 255, "minimum": 1, "type": "number"}, "outside": {"default": 0, "type": "number", "description": "Configure interface as outside", "format": "flag"}, "helper-address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"helper-address": {"type": "string", "description": "Helper address for DHCP packets (IP address)", "format": "ipv4-address"}, "optional": true}}]}, "stateful-firewall": {"type": "object", "properties": {"access-list": {"default": 0, "type": "number", "description": "Access-list for traffic from the outside", "format": "flag"}, "inside": {"default": 0, "type": "number", "description": "Inside (private) interface for stateful firewall", "format": "flag"}, "acl-id": {"description": "ACL id", "minimum": 1, "type": "number", "maximum": 199, "format": "number"}, "outside": {"default": 0, "type": "number", "description": "Outside (public) interface for stateful firewall", "format": "flag"}}}, "rip": {"type": "object", "properties": {"receive-cfg": {"type": "object", "properties": {"receive": {"default": 0, "type": "number", "description": "Advertisement reception", "format": "flag"}, "version": {"enum": ["1", "2", "1-2"], "type": "string", "description": "'1': RIP version 1; '2': RIP version 2; '1-2': RIP version 1 & 2; ", "format": "enum"}}}, "receive-packet": {"default": 1, "type": "number", "description": "Enable receiving packet through the specified interface", "format": "flag"}, "split-horizon-cfg": {"type": "object", "properties": {"state": {"default": "poisoned", "enum": ["poisoned", "disable", "enable"], "type": "string", "description": "'poisoned': Perform split horizon with poisoned reverse; 'disable': Disable split horizon; 'enable': Perform split horizon without poisoned reverse; ", "format": "enum"}}}, "authentication": {"type": "object", "properties": {"key-chain": {"type": "object", "properties": {"key-chain": {"type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string-rlx"}}}, "mode": {"type": "object", "properties": {"mode": {"default": "text", "enum": ["md5", "text"], "type": "string", "description": "'md5': Keyed message digest; 'text': Clear text authentication; ", "format": "enum"}}}, "str": {"type": "object", "properties": {"string": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The RIP authentication string", "format": "string-rlx"}}}}}, "send-cfg": {"type": "object", "properties": {"version": {"enum": ["1", "2", "1-compatible", "1-2"], "type": "string", "description": "'1': RIP version 1; '2': RIP version 2; '1-compatible': RIPv1-compatible; '1-2': RIP version 1 & 2; ", "format": "enum"}, "send": {"default": 0, "type": "number", "description": "Advertisement transmission", "format": "flag"}}}, "send-packet": {"default": 1, "type": "number", "description": "Enable sending packets through the specified interface", "format": "flag"}}}, "router": {"type": "object", "properties": {"isis": {"type": "object", "properties": {"tag": {"description": "ISO routing area tag", "format": "string", "minLength": 1, "modify-not-allowed": 1, "maxLength": 128, "type": "string"}}}}}, "dhcp": {"default": 0, "type": "number", "description": "Use DHCP to configure IP address", "format": "flag"}, "ospf": {"type": "object", "properties": {"ospf-ip-list": {"minItems": 1, "items": {"type": "ospf-ip"}, "uniqueItems": true, "array": [{"required": ["ip-addr"], "properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication-key": {"description": "Authentication password (key) (The OSPF password (key))", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 8, "type": "string"}, "mtu-ignore": {"default": 0, "optional": true, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "priority": {"description": "Router priority", "format": "number", "default": 1, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "value": {"optional": true, "enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use no authentication; ", "format": "enum"}, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication": {"default": 0, "optional": true, "type": "number", "description": "Enable authentication", "format": "flag"}, "cost": {"description": "Interface cost", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "database-filter": {"optional": true, "enum": ["all"], "type": "string", "description": "'all': Filter all LSA; ", "format": "enum"}, "ip-addr": {"optional": false, "type": "string", "description": "Address of interface", "format": "ipv4-address"}, "retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "message-digest-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"md5-value": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}, "message-digest-key": {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}]}, "out": {"default": 0, "optional": true, "type": "number", "description": "Outgoing LSA", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/interface/ve/{ifnum}/ip/ospf/ospf-ip/{ip-addr}"}, "ospf-global": {"type": "object", "properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication-key": {"minLength": 1, "maxLength": 8, "type": "string", "description": "Authentication password (key) (The OSPF password (key))", "format": "string-rlx"}, "network": {"type": "object", "properties": {"broadcast": {"default": 0, "not-list": ["non-broadcast", "point-to-point", "point-to-multipoint"], "type": "number", "description": "Specify OSPF broadcast multi-access network", "format": "flag"}, "point-to-multipoint": {"default": 0, "not-list": ["broadcast", "non-broadcast", "point-to-point"], "type": "number", "description": "Specify OSPF point-to-multipoint network", "format": "flag"}, "non-broadcast": {"default": 0, "not-list": ["broadcast", "point-to-point", "point-to-multipoint"], "type": "number", "description": "Specify OSPF NBMA network", "format": "flag"}, "point-to-point": {"default": 0, "not-list": ["broadcast", "non-broadcast", "point-to-multipoint"], "type": "number", "description": "Specify OSPF point-to-point network", "format": "flag"}, "p2mp-nbma": {"default": 0, "type": "number", "description": "Specify non-broadcast point-to-multipoint network", "format": "flag"}}}, "mtu-ignore": {"default": 0, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "maximum": 65535, "minimum": 1, "type": "number"}, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "disable": {"enum": ["all"], "type": "string", "description": "'all': All functionality; ", "format": "enum"}, "authentication-cfg": {"type": "object", "properties": {"authentication": {"default": 0, "type": "number", "description": "Enable authentication", "format": "flag"}, "value": {"enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use no authentication; ", "format": "enum"}}}, "database-filter-cfg": {"type": "object", "properties": {"database-filter": {"enum": ["all"], "type": "string", "description": "'all': Filter all LSA; ", "format": "enum"}, "out": {"default": 0, "type": "number", "description": "Outgoing LSA", "format": "flag"}}}, "bfd-cfg": {"type": "object", "properties": {"disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}}}, "cost": {"description": "Interface cost", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "mtu": {"description": "OSPF interface MTU (MTU size)", "minimum": 576, "type": "number", "maximum": 65535, "format": "number"}, "message-digest-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"message-digest-key": {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "md5": {"type": "object", "properties": {"md5-value": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}, "encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}}}]}, "priority": {"description": "Router priority", "format": "number", "default": 1, "maximum": 255, "minimum": 0, "type": "number"}}}}}, "slb-partition-redirect": {"default": 0, "type": "number", "description": "Redirect SLB traffic across partition", "format": "flag"}}}, "icmpv6-rate-limit": {"type": "object", "properties": {"lockup-period-v6": {"description": "Lockup period (second)", "minimum": 1, "type": "number", "maximum": 16383, "format": "number"}, "normal-v6": {"description": "Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "lockup-v6": {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}, "mtu": {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Interface mtu (Interface MTU, default 1500 (min MTU is 1280 for IPv6))", "format": "number", "optional": true, "type": "number"}, "access-list": {"type": "object", "properties": {"acl-name": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Named Access List", "format": "string"}, "acl-id": {"description": "ACL id", "format": "number", "maximum": 199, "$ref-list": ["/axapi/v3/access-list/standard", "/axapi/v3/access-list/extended"], "minimum": 1, "type": "number"}}}, "ifnum": {"optional": false, "$ref": "/axapi/v3/network/vlan", "type": "number", "description": "Virtual ethernet interface number", "format": "number"}, "lw-4o6": {"type": "object", "properties": {"outside": {"default": 0, "type": "number", "description": "Configure LW-4over6 inside interface", "format": "flag"}, "inside": {"default": 0, "type": "number", "description": "Configure LW-4over6 outside interface", "format": "flag"}}}, "ipv6": {"type": "object", "properties": {"inbound": {"default": 0, "type": "number", "description": "ACL applied on incoming packets to this interface", "format": "flag"}, "address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"address-type": {"enum": ["anycast", "link-local"], "type": "string", "description": "'anycast': Configure an IPv6 anycast address; 'link-local': Configure an IPv6 link local address; ", "format": "enum"}, "ipv6-addr": {"type": "string", "description": "Set the IPv6 address of an interface", "format": "ipv6-address-plen"}, "optional": true}}]}, "inside": {"default": 0, "type": "number", "description": "Configure interface as NAT inside", "format": "flag"}, "outside": {"default": 0, "type": "number", "description": "Configure interface as NAT outside", "format": "flag"}, "rip": {"type": "object", "properties": {"split-horizon-cfg": {"type": "object", "properties": {"state": {"default": "poisoned", "enum": ["poisoned", "disable", "enable"], "type": "string", "description": "'poisoned': Perform split horizon with poisoned reverse; 'disable': Disable split horizon; 'enable': Perform split horizon without poisoned reverse; ", "format": "enum"}}}}}, "ipv6-enable": {"default": 0, "type": "number", "description": "Enable IPv6 processing", "format": "flag"}, "stateful-firewall": {"type": "object", "properties": {"access-list": {"default": 0, "type": "number", "description": "Access-list for traffic from the outside", "format": "flag"}, "acl-name": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Access-list Name", "format": "string"}, "inside": {"default": 0, "type": "number", "description": "Inside (private) interface for stateful firewall", "format": "flag"}, "outside": {"default": 0, "type": "number", "description": "Outside (public) interface for stateful firewall", "format": "flag"}}}, "v6-acl-name": {"description": "Apply ACL rules to incoming packets on this interface (Named Access List)", "format": "string", "minLength": 1, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ipv6/access-list"}, "router": {"type": "object", "properties": {"ripng": {"type": "object", "properties": {"rip": {"default": 0, "type": "number", "description": "RIP Routing for IPv6", "format": "flag"}}}, "ospf": {"type": "object", "properties": {"area-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"area-id-addr": {"type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}, "tag": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Set the OSPFv3 process tag", "format": "string"}, "optional": true, "instance-id": {"description": "Set the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}, "area-id-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}}}]}}}, "isis": {"type": "object", "properties": {"tag": {"description": "ISO routing area tag", "format": "string", "minLength": 1, "modify-not-allowed": 1, "maxLength": 128, "type": "string"}}}}}, "ospf": {"type": "object", "properties": {"bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "cost-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cost": {"description": "Interface cost", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "hello-interval-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "priority-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Router priority", "format": "number", "default": 1, "maximum": 255, "minimum": 0, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "mtu-ignore-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"mtu-ignore": {"default": 0, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "retransmit-interval-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "maximum": 65535, "minimum": 1, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "network-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"broadcast-type": {"enum": ["broadcast", "non-broadcast", "point-to-point", "point-to-multipoint"], "type": "string", "description": "'broadcast': Specify OSPF broadcast multi-access network; 'non-broadcast': Specify OSPF NBMA network; 'point-to-point': Specify OSPF point-to-point network; 'point-to-multipoint': Specify OSPF point-to-multipoint network; ", "format": "enum"}, "optional": true, "p2mp-nbma": {"default": 0, "type": "number", "description": "Specify non-broadcast point-to-multipoint network", "format": "flag"}, "network-instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "transmit-delay-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "neighbor-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"neighbor-priority": {"description": "OSPF priority of non-broadcast neighbor", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}, "neig-inst": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}, "neighbor-poll-interval": {"description": "OSPF dead-router polling interval (Seconds)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "neighbor-cost": {"description": "OSPF cost for point-to-multipoint neighbor (metric)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "neighbor": {"default": "::", "type": "string", "description": "OSPFv3 neighbor (Neighbor IPv6 address)", "format": "ipv6-address"}, "optional": true}}]}, "dead-interval-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "maximum": 65535, "minimum": 1, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}}}, "router-adver": {"type": "object", "properties": {"max-interval": {"description": "Set Router Advertisement Max Interval (default: 600) (Max Router Advertisement Interval (seconds))", "format": "number", "default": 600, "maximum": 1800, "minimum": 4, "type": "number"}, "default-lifetime": {"description": "Set Router Advertisement Default Lifetime (default: 1800) (Default Lifetime (seconds))", "format": "number", "default": 1800, "maximum": 9000, "minimum": 0, "type": "number"}, "ha-use-floating-ip": {"default": 0, "type": "number", "description": "Use a floating IP as the source address for Router advertisements", "format": "flag"}, "reachable-time": {"description": "Set Router Advertisement Reachable ime (default: 0) (Reachable Time (milliseconds))", "format": "number", "default": 0, "maximum": 3600000, "minimum": 0, "type": "number"}, "adver-ha-group-id": {"description": "HA Group ID", "minimum": 1, "type": "number", "maximum": 31, "format": "number"}, "ha-floating-ip": {"type": "string", "description": "Floating Point IPv6 address", "format": "ipv6-address"}, "prefix-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"not-autonomous": {"default": 0, "type": "number", "description": "Specify that the Prefix is not usable for autoconfiguration (default:autonomous)", "format": "flag"}, "valid-lifetime": {"description": "Specify Valid Lifetime (default:2592000) (Prefix Advertised Valid Lifetime (default: 2592000))", "format": "number", "default": 2592000, "maximum": 4294967295, "minimum": 0, "type": "number"}, "not-on-link": {"default": 0, "type": "number", "description": "Specify that the Prefix is not On-Link (default: on-link)", "format": "flag"}, "prefix": {"type": "string", "description": "Set Router Advertisement On-Link Prefix (IPv6 On-Link Prefix)", "format": "ipv6-address-plen"}, "preferred-lifetime": {"description": "Specify Prefix Preferred Lifetime (default:604800) (Prefix Advertised Preferred Lifetime (default: 604800))", "format": "number", "default": 604800, "maximum": 4294967295, "minimum": 0, "type": "number"}, "optional": true}}]}, "rate-limit": {"description": "Rate Limit the processing of incoming Router Solicitations (Max Number of Router Solicitations to process per second)", "format": "number", "default": 100000, "maximum": 100000, "minimum": 1, "type": "number"}, "adver-mtu-disable": {"default": 0, "not": "adver-mtu", "type": "number", "description": "Disable Router Advertisement MTU Option", "format": "flag"}, "min-interval": {"description": "Set Router Advertisement Min Interval (default: 200) (Min Router Advertisement Interval (seconds))", "format": "number", "default": 200, "maximum": 1350, "minimum": 3, "type": "number"}, "floating-ip": {"type": "string", "description": "Floating Point IPv6 address", "format": "ipv6-address"}, "adver-vrid": {"description": "Vrid", "format": "number", "maximum": 31, "minimum": 1, "not": "adver-vrid-default", "type": "number"}, "action": {"default": "enable", "enum": ["enable", "disable"], "type": "string", "description": "'enable': Enable Router Advertisements on this interface; 'disable': Disable Router Advertisements on this interface; ", "format": "enum"}, "adver-vrid-default": {"default": 0, "not": "adver-vrid", "type": "number", "description": "Default Value", "format": "flag"}, "adver-mtu": {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Set Router Advertisement MTU Option", "format": "number", "not": "adver-mtu-disable", "type": "number"}, "retransmit-timer": {"description": "Set Router Advertisement Retransmit Timer (default: 0)", "format": "number", "default": 0, "maximum": 4294967295, "minimum": 0, "type": "number"}, "hop-limit": {"description": "Set Router Advertisement Hop Limit (default: 255)", "format": "number", "default": 255, "maximum": 255, "minimum": 0, "type": "number"}, "use-floating-ip": {"default": 0, "type": "number", "description": "Use a floating IP as the source address for Router advertisements", "format": "flag"}}}}}, "action": {"optional": true, "enum": ["enable", "disable"], "type": "string", "description": "'enable': Enable; 'disable': Disable; ", "format": "enum"}, "l3-vlan-fwd-disable": {"default": 0, "optional": true, "type": "number", "description": "Disable L3 forwarding between VLANs for incoming packets on this interface", "format": "flag"}, "ddos": {"type": "object", "properties": {"outside": {"default": 0, "type": "number", "description": "DDoS inside (trusted) or outside (untrusted) interface", "format": "flag"}, "inside": {"default": 0, "type": "number", "description": "DDoS inside (trusted) or outside (untrusted) interface", "format": "flag"}}}}}], "type": "array", "$ref": "/axapi/v3/interface/ve/{ifnum}"}
    :param ethernet_list: {"minItems": 1, "items": {"type": "ethernet"}, "uniqueItems": true, "array": [{"required": ["ifnum"], "properties": {"trap-source": {"default": 0, "optional": true, "type": "number", "description": "The trap source", "format": "flag"}, "ip": {"type": "object", "properties": {"generate-membership-query": {"default": 0, "type": "number", "description": "Enable Membership Query", "format": "flag"}, "cache-spoofing-port": {"default": 0, "type": "number", "description": "This interface connects to spoofing cache", "format": "flag"}, "inside": {"default": 0, "type": "number", "description": "Configure interface as inside", "format": "flag"}, "router": {"type": "object", "properties": {"isis": {"type": "object", "properties": {"tag": {"description": "ISO routing area tag", "format": "string", "minLength": 1, "modify-not-allowed": 1, "maxLength": 128, "type": "string"}}}}}, "allow-promiscuous-vip": {"default": 0, "type": "number", "description": "Allow traffic to be associated with promiscuous VIP", "format": "flag"}, "max-resp-time": {"description": "Maximum Response Time (Max Response Time (Default is 100))", "format": "number", "default": 100, "maximum": 255, "minimum": 1, "type": "number"}, "query-interval": {"description": "1 - 255 (Default is 125)", "format": "number", "default": 125, "maximum": 255, "minimum": 1, "type": "number"}, "outside": {"default": 0, "type": "number", "description": "Configure interface as outside", "format": "flag"}, "helper-address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"helper-address": {"type": "string", "description": "Helper address for DHCP packets (IP address)", "format": "ipv4-address"}, "optional": true}}]}, "stateful-firewall": {"type": "object", "properties": {"access-list": {"default": 0, "type": "number", "description": "Access-list for traffic from the outside", "format": "flag"}, "inside": {"default": 0, "type": "number", "description": "Inside (private) interface for stateful firewall", "format": "flag"}, "acl-id": {"description": "ACL id", "minimum": 1, "type": "number", "maximum": 199, "format": "number"}, "outside": {"default": 0, "type": "number", "description": "Outside (public) interface for stateful firewall", "format": "flag"}}}, "rip": {"type": "object", "properties": {"receive-cfg": {"type": "object", "properties": {"receive": {"default": 0, "type": "number", "description": "Advertisement reception", "format": "flag"}, "version": {"enum": ["1", "2", "1-2"], "type": "string", "description": "'1': RIP version 1; '2': RIP version 2; '1-2': RIP version 1 & 2; ", "format": "enum"}}}, "receive-packet": {"default": 1, "type": "number", "description": "Enable receiving packet through the specified interface", "format": "flag"}, "split-horizon-cfg": {"type": "object", "properties": {"state": {"default": "poisoned", "enum": ["poisoned", "disable", "enable"], "type": "string", "description": "'poisoned': Perform split horizon with poisoned reverse; 'disable': Disable split horizon; 'enable': Perform split horizon without poisoned reverse; ", "format": "enum"}}}, "authentication": {"type": "object", "properties": {"key-chain": {"type": "object", "properties": {"key-chain": {"type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string-rlx"}}}, "mode": {"type": "object", "properties": {"mode": {"default": "text", "enum": ["md5", "text"], "type": "string", "description": "'md5': Keyed message digest; 'text': Clear text authentication; ", "format": "enum"}}}, "str": {"type": "object", "properties": {"string": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The RIP authentication string", "format": "string-rlx"}}}}}, "send-cfg": {"type": "object", "properties": {"version": {"enum": ["1", "2", "1-compatible", "1-2"], "type": "string", "description": "'1': RIP version 1; '2': RIP version 2; '1-compatible': RIPv1-compatible; '1-2': RIP version 1 & 2; ", "format": "enum"}, "send": {"default": 0, "type": "number", "description": "Advertisement transmission", "format": "flag"}}}, "send-packet": {"default": 1, "type": "number", "description": "Enable sending packets through the specified interface", "format": "flag"}}}, "address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv4-address": {"type": "string", "description": "IP address", "format": "ipv4-address"}, "optional": true, "ipv4-netmask": {"type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}}}]}, "dhcp": {"default": 0, "type": "number", "description": "Use DHCP to configure IP address", "format": "flag"}, "ospf": {"type": "object", "properties": {"ospf-ip-list": {"minItems": 1, "items": {"type": "ospf-ip"}, "uniqueItems": true, "array": [{"required": ["ip-addr"], "properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication-key": {"description": "Authentication password (key) (The OSPF password (key))", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 8, "type": "string"}, "mtu-ignore": {"default": 0, "optional": true, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "priority": {"description": "Router priority", "format": "number", "default": 1, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "value": {"optional": true, "enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use no authentication; ", "format": "enum"}, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication": {"default": 0, "optional": true, "type": "number", "description": "Enable authentication", "format": "flag"}, "cost": {"description": "Interface cost", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "database-filter": {"optional": true, "enum": ["all"], "type": "string", "description": "'all': Filter all LSA; ", "format": "enum"}, "ip-addr": {"optional": false, "type": "string", "description": "Address of interface", "format": "ipv4-address"}, "retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "message-digest-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"md5-value": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}, "message-digest-key": {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}]}, "out": {"default": 0, "optional": true, "type": "number", "description": "Outgoing LSA", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/interface/ethernet/{ifnum}/ip/ospf/ospf-ip/{ip-addr}"}, "ospf-global": {"type": "object", "properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication-key": {"minLength": 1, "maxLength": 8, "type": "string", "description": "Authentication password (key) (The OSPF password (key))", "format": "string-rlx"}, "network": {"type": "object", "properties": {"broadcast": {"default": 0, "not-list": ["non-broadcast", "point-to-point", "point-to-multipoint"], "type": "number", "description": "Specify OSPF broadcast multi-access network", "format": "flag"}, "point-to-multipoint": {"default": 0, "not-list": ["broadcast", "non-broadcast", "point-to-point"], "type": "number", "description": "Specify OSPF point-to-multipoint network", "format": "flag"}, "non-broadcast": {"default": 0, "not-list": ["broadcast", "point-to-point", "point-to-multipoint"], "type": "number", "description": "Specify OSPF NBMA network", "format": "flag"}, "point-to-point": {"default": 0, "not-list": ["broadcast", "non-broadcast", "point-to-multipoint"], "type": "number", "description": "Specify OSPF point-to-point network", "format": "flag"}, "p2mp-nbma": {"default": 0, "type": "number", "description": "Specify non-broadcast point-to-multipoint network", "format": "flag"}}}, "mtu-ignore": {"default": 0, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "maximum": 65535, "minimum": 1, "type": "number"}, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "disable": {"enum": ["all"], "type": "string", "description": "'all': All functionality; ", "format": "enum"}, "authentication-cfg": {"type": "object", "properties": {"authentication": {"default": 0, "type": "number", "description": "Enable authentication", "format": "flag"}, "value": {"enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use no authentication; ", "format": "enum"}}}, "database-filter-cfg": {"type": "object", "properties": {"database-filter": {"enum": ["all"], "type": "string", "description": "'all': Filter all LSA; ", "format": "enum"}, "out": {"default": 0, "type": "number", "description": "Outgoing LSA", "format": "flag"}}}, "bfd-cfg": {"type": "object", "properties": {"disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}}}, "cost": {"description": "Interface cost", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "mtu": {"description": "OSPF interface MTU (MTU size)", "minimum": 576, "type": "number", "maximum": 65535, "format": "number"}, "message-digest-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"message-digest-key": {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "md5": {"type": "object", "properties": {"md5-value": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}, "encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}}}]}, "priority": {"description": "Router priority", "format": "number", "default": 1, "maximum": 255, "minimum": 0, "type": "number"}}}}}, "slb-partition-redirect": {"default": 0, "type": "number", "description": "Redirect SLB traffic across partition", "format": "flag"}}}, "ddos": {"type": "object", "properties": {"outside": {"default": 0, "type": "number", "description": "DDoS outside (untrusted) interface", "format": "flag"}, "inside": {"default": 0, "type": "number", "description": "DDoS inside (trusted) interface", "format": "flag"}}}, "access-list": {"type": "object", "properties": {"acl-name": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Apply an access list (Named Access List)", "format": "string"}, "acl-id": {"description": "ACL id", "format": "number", "maximum": 199, "$ref-list": ["/axapi/v3/access-list/standard", "/axapi/v3/access-list/extended"], "minimum": 1, "type": "number"}}}, "speed": {"description": "'10': 10; '100': 100; '1000': 1000; 'auto': auto; ", "format": "enum", "default": "auto", "optional": true, "enum": ["10", "100", "1000", "auto"], "type": "string", "plat-neg-list": ["soft-ax"]}, "lldp": {"type": "object", "properties": {"tx-dot1-cfg": {"type": "object", "properties": {"link-aggregation": {"default": 0, "type": "number", "description": "Interface link aggregation information", "format": "flag"}, "vlan": {"default": 0, "type": "number", "description": "Interface vlan information", "format": "flag"}, "tx-dot1-tlvs": {"default": 0, "type": "number", "description": "Interface lldp tx IEEE 802.1 Organizationally specific TLVs configuration", "format": "flag"}}}, "notification-cfg": {"type": "object", "properties": {"notification": {"default": 0, "type": "number", "description": "Interface lldp notification configuration", "format": "flag"}, "notif-enable": {"default": 0, "type": "number", "description": "Interface lldp notification enable", "format": "flag"}}}, "tx-tlvs-cfg": {"type": "object", "properties": {"system-capabilities": {"default": 0, "type": "number", "description": "Interface lldp system capabilities", "format": "flag"}, "system-description": {"default": 0, "type": "number", "description": "Interface lldp system description", "format": "flag"}, "management-address": {"default": 0, "type": "number", "description": "Interface lldp management address", "format": "flag"}, "tx-tlvs": {"default": 0, "type": "number", "description": "Interface lldp tx TLVs configuration", "format": "flag"}, "exclude": {"default": 0, "type": "number", "description": "Configure which TLVs excluded. All basic TLVs will be included by default", "format": "flag"}, "port-description": {"default": 0, "type": "number", "description": "Interface lldp port description", "format": "flag"}, "system-name": {"default": 0, "type": "number", "description": "Interface lldp system name", "format": "flag"}}}, "enable-cfg": {"type": "object", "properties": {"rx": {"default": 0, "type": "number", "description": "Enable lldp rx", "format": "flag"}, "tx": {"default": 0, "type": "number", "description": "Enable lldp tx", "format": "flag"}, "rt-enable": {"default": 0, "type": "number", "description": "Interface lldp enable/disable", "format": "flag"}}}}}, "bfd": {"type": "object", "properties": {"authentication": {"type": "object", "properties": {"encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "password": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Key String", "format": "password"}, "method": {"enum": ["md5", "meticulous-md5", "meticulous-sha1", "sha1", "simple"], "type": "string", "description": "'md5': Keyed MD5; 'meticulous-md5': Meticulous Keyed MD5; 'meticulous-sha1': Meticulous Keyed SHA1; 'sha1': Keyed SHA1; 'simple': Simple Password; ", "format": "enum"}, "key-id": {"description": "Key ID", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}}}, "demand": {"default": 0, "type": "number", "description": "Demand mode", "format": "flag"}, "interval-cfg": {"type": "object", "properties": {"interval": {"description": "Transmit interval between BFD packets (Milliseconds)", "minimum": 48, "type": "number", "maximum": 1000, "format": "number"}, "min-rx": {"description": "Minimum receive interval capability (Milliseconds)", "minimum": 48, "type": "number", "maximum": 1000, "format": "number"}, "multiplier": {"description": "Multiplier value used to compute holddown (value used to multiply the interval)", "minimum": 3, "type": "number", "maximum": 50, "format": "number"}}}, "echo": {"default": 0, "type": "number", "description": "Enable BFD Echo", "format": "flag"}}}, "media-type-copper": {"description": "Set the media type to copper", "format": "flag", "default": 0, "type": "number", "optional": true, "plat-neg-list": ["non-fpga", "soft-ax"]}, "remove-vlan-tag": {"description": "Remove the vlan tag for egressing packets", "format": "flag", "default": 0, "type": "number", "optional": true, "plat-neg-list": ["non-fpga", "soft-ax"]}, "load-interval": {"description": "Configure Load Interval (Seconds (5-300, Multiple of 5), default 300)", "format": "number", "default": 300, "optional": true, "maximum": 300, "minimum": 5, "type": "number"}, "cpu-process": {"description": "All Packets to this port are processed by CPU", "format": "flag", "default": 0, "type": "number", "optional": true, "plat-neg-list": ["non-fpga", "soft-ax"]}, "ipv6": {"type": "object", "properties": {"address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"address-type": {"enum": ["anycast", "link-local"], "type": "string", "description": "'anycast': Configure an IPv6 anycast address; 'link-local': Configure an IPv6 link local address; ", "format": "enum"}, "ipv6-addr": {"type": "string", "description": "Set the IPv6 address of an interface", "format": "ipv6-address-plen"}, "optional": true}}]}, "router-adver": {"type": "object", "properties": {"max-interval": {"description": "Set Router Advertisement Max Interval (default: 600) (Max Router Advertisement Interval (seconds))", "format": "number", "default": 600, "maximum": 1800, "minimum": 4, "type": "number"}, "default-lifetime": {"description": "Set Router Advertisement Default Lifetime (default: 1800) (Default Lifetime (seconds))", "format": "number", "default": 1800, "maximum": 9000, "minimum": 0, "type": "number"}, "ha-use-floating-ip": {"default": 0, "type": "number", "description": "Use a floating IP as the source address for Router advertisements", "format": "flag"}, "reachable-time": {"description": "Set Router Advertisement Reachable ime (default: 0) (Reachable Time (milliseconds))", "format": "number", "default": 0, "maximum": 3600000, "minimum": 0, "type": "number"}, "adver-ha-group-id": {"description": "HA Group ID", "minimum": 1, "type": "number", "maximum": 31, "format": "number"}, "ha-floating-ip": {"type": "string", "description": "Use a floating IP as the source address for Router advertisements", "format": "ipv6-address"}, "prefix-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"not-autonomous": {"default": 0, "type": "number", "description": "Specify that the Prefix is not usable for autoconfiguration (default:autonomous)", "format": "flag"}, "valid-lifetime": {"description": "Specify Valid Lifetime (default:2592000) (Prefix Advertised Valid Lifetime (default: 2592000))", "format": "number", "default": 2592000, "maximum": 4294967295, "minimum": 0, "type": "number"}, "not-on-link": {"default": 0, "type": "number", "description": "Specify that the Prefix is not On-Link (default: on-link)", "format": "flag"}, "prefix": {"type": "string", "description": "Set Router Advertisement On-Link Prefix (IPv6 On-Link Prefix)", "format": "ipv6-address-plen"}, "preferred-lifetime": {"description": "Specify Prefix Preferred Lifetime (default:604800) (Prefix Advertised Preferred Lifetime (default: 604800))", "format": "number", "default": 604800, "maximum": 4294967295, "minimum": 0, "type": "number"}, "optional": true}}]}, "rate-limit": {"description": "Rate Limit the processing of incoming Router Solicitations (Max Number of Router Solicitations to process per second)", "format": "number", "default": 100000, "maximum": 100000, "minimum": 1, "type": "number"}, "adver-mtu-disable": {"default": 0, "not": "adver-mtu", "type": "number", "description": "Disable Router Advertisement MTU Option", "format": "flag"}, "min-interval": {"description": "Set Router Advertisement Min Interval (default: 200) (Min Router Advertisement Interval (seconds))", "format": "number", "default": 200, "maximum": 1350, "minimum": 3, "type": "number"}, "floating-ip": {"type": "string", "description": "Use a floating IP as the source address for Router advertisements", "format": "ipv6-address"}, "adver-vrid": {"description": "Specify ha VRRP-A vrid", "partition-visibility": "shared", "format": "number", "maximum": 31, "minimum": 1, "not": "adver-vrid-default", "type": "number"}, "action": {"default": "enable", "enum": ["enable", "disable"], "type": "string", "description": "'enable': Enable Router Advertisements on this interface; 'disable': Disable Router Advertisements on this interface; ", "format": "enum"}, "adver-vrid-default": {"default": 0, "not": "adver-vrid", "type": "number", "description": "Default VRRP-A vrid", "format": "flag"}, "adver-mtu": {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Set Router Advertisement MTU Option", "format": "number", "not": "adver-mtu-disable", "type": "number"}, "retransmit-timer": {"description": "Set Router Advertisement Retransmit Timer (default: 0)", "format": "number", "default": 0, "maximum": 4294967295, "minimum": 0, "type": "number"}, "hop-limit": {"description": "Set Router Advertisement Hop Limit (default: 255)", "format": "number", "default": 255, "maximum": 255, "minimum": 0, "type": "number"}, "use-floating-ip": {"default": 0, "type": "number", "description": "Use a floating IP as the source address for Router advertisements", "format": "flag"}}}, "outside": {"default": 0, "type": "number", "description": "Configure interface as outside", "format": "flag"}, "rip": {"type": "object", "properties": {"split-horizon-cfg": {"type": "object", "properties": {"state": {"default": "poisoned", "enum": ["poisoned", "disable", "enable"], "type": "string", "description": "'poisoned': Perform split horizon with poisoned reverse; 'disable': Disable split horizon; 'enable': Perform split horizon without poisoned reverse; ", "format": "enum"}}}}}, "ipv6-enable": {"default": 0, "type": "number", "description": "Enable IPv6 processing", "format": "flag"}, "stateful-firewall": {"type": "object", "properties": {"access-list": {"default": 0, "type": "number", "description": "Access-list for traffic from the outside", "format": "flag"}, "acl-name": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Access-list Name", "format": "string"}, "inside": {"default": 0, "type": "number", "description": "Inside (private) interface for stateful firewall", "format": "flag"}, "outside": {"default": 0, "type": "number", "description": "Outside (public) interface for stateful firewall", "format": "flag"}}}, "router": {"type": "object", "properties": {"ripng": {"type": "object", "properties": {"rip": {"default": 0, "type": "number", "description": "RIP Routing for IPv6", "format": "flag"}}}, "ospf": {"type": "object", "properties": {"area-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"area-id-addr": {"type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}, "tag": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Set the OSPFv3 process tag", "format": "string"}, "optional": true, "instance-id": {"description": "Set the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}, "area-id-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}}}]}}}, "isis": {"type": "object", "properties": {"tag": {"description": "ISO routing area tag", "format": "string", "minLength": 1, "modify-not-allowed": 1, "maxLength": 128, "type": "string"}}}}}, "access-list-cfg": {"type": "object", "properties": {"inbound": {"default": 0, "type": "number", "description": "ACL applied on incoming packets to this interface", "format": "flag"}, "v6-acl-name": {"description": "Apply ACL rules to incoming packets on this interface (Named Access List)", "format": "string", "minLength": 1, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ipv6/access-list"}}}, "ospf": {"type": "object", "properties": {"bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "cost-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cost": {"description": "Interface cost", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "hello-interval-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "priority-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Router priority", "format": "number", "default": 1, "maximum": 255, "minimum": 0, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "mtu-ignore-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"mtu-ignore": {"default": 0, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "retransmit-interval-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "maximum": 65535, "minimum": 1, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "network-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"broadcast-type": {"enum": ["broadcast", "non-broadcast", "point-to-point", "point-to-multipoint"], "type": "string", "description": "'broadcast': Specify OSPF broadcast multi-access network; 'non-broadcast': Specify OSPF NBMA network; 'point-to-point': Specify OSPF point-to-point network; 'point-to-multipoint': Specify OSPF point-to-multipoint network; ", "format": "enum"}, "optional": true, "p2mp-nbma": {"default": 0, "type": "number", "description": "Specify non-broadcast point-to-multipoint network", "format": "flag"}, "network-instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "transmit-delay-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "neighbor-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"neighbor-priority": {"description": "OSPF priority of non-broadcast neighbor", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}, "neig-inst": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}, "neighbor-poll-interval": {"description": "OSPF dead-router polling interval (Seconds)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "neighbor-cost": {"description": "OSPF cost for point-to-multipoint neighbor (metric)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "neighbor": {"default": "::", "type": "string", "description": "OSPFv3 neighbor (Neighbor IPv6 address)", "format": "ipv6-address"}, "optional": true}}]}, "dead-interval-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "maximum": 65535, "minimum": 1, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}}}, "inside": {"default": 0, "type": "number", "description": "Configure interface as inside", "format": "flag"}}}, "trunk-group-list": {"minItems": 1, "items": {"type": "trunk-group"}, "uniqueItems": true, "array": [{"required": ["trunk-number"], "properties": {"trunk-number": {"description": "Trunk Number", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": false}, "udld-timeout-cfg": {"type": "object", "properties": {"slow": {"description": "slow timeout in unit of seconds", "format": "number", "default": 1, "maximum": 60, "minimum": 1, "not": "fast", "type": "number"}, "fast": {"description": "fast timeout in unit of milli-seconds", "format": "number", "default": 1000, "maximum": 1000, "minimum": 100, "not": "slow", "type": "number"}}}, "mode": {"description": "'active': enable initiation of LACP negotiation on a port(default); 'passive': disable initiation of LACP negotiation on a port; ", "format": "enum", "default": "active", "type": "string", "enum": ["active", "passive"], "optional": true}, "timeout": {"description": "'long': Set LACP long timeout (default); 'short': Set LACP short timeout; ", "format": "enum", "default": "long", "type": "string", "enum": ["long", "short"], "optional": true}, "type": {"description": "'static': Static (default); 'lacp': lacp; 'lacp-udld': lacp-udld; ", "format": "enum", "default": "static", "optional": true, "enum": ["static", "lacp", "lacp-udld"], "modify-not-allowed": 1, "type": "string"}, "admin-key": {"description": "LACP admin key (Admin key value)", "format": "number", "type": "number", "maximum": 65535, "minimum": 10000, "optional": true}, "port-priority": {"description": "Set LACP priority for a port (LACP port priority)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/interface/ethernet/{ifnum}/trunk-group/{trunk-number}"}, "l3-vlan-fwd-disable": {"default": 0, "optional": true, "type": "number", "format": "flag"}, "isis": {"type": "object", "properties": {"priority-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Set priority for Designated Router election (Priority value)", "format": "number", "default": 64, "maximum": 127, "minimum": 0, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify priority for level-1 routing; 'level-2': Specify priority for level-2 routing; ", "format": "enum"}}}]}, "hello-interval-minimal-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"hello-interval-minimal": {"default": 0, "type": "number", "description": "Set Hello holdtime 1 second, interval depends on multiplier", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}}}]}, "mesh-group": {"type": "object", "properties": {"value": {"description": "Mesh group number", "format": "number", "maximum": 4294967295, "minimum": 1, "not": "blocked", "type": "number"}, "blocked": {"default": 0, "not": "value", "type": "number", "description": "Block LSPs on this interface", "format": "flag"}}}, "network": {"enum": ["broadcast", "point-to-point"], "type": "string", "description": "'broadcast': Specify IS-IS broadcast multi-access network; 'point-to-point': Specify IS-IS point-to-point network; ", "format": "enum"}, "bfd-cfg": {"type": "object", "properties": {"disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}}}, "csnp-interval-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Speficy interval for level-1 CSNPs; 'level-2': Specify interval for level-2 CSNPs; ", "format": "enum"}, "optional": true, "csnp-interval": {"description": "Set CSNP interval in seconds (CSNP interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}}}]}, "retransmit-interval": {"description": "Set per-LSP retransmission interval (Interval between retransmissions of the same LSP (seconds))", "format": "number", "default": 5, "maximum": 65535, "minimum": 0, "type": "number"}, "password-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"password": {"minLength": 1, "maxLength": 254, "type": "string", "description": "Configure the authentication password for interface", "format": "string-rlx"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify password for level-1 PDUs; 'level-2': Specify password for level-2 PDUs; ", "format": "enum"}}}]}, "authentication": {"type": "object", "properties": {"key-chain-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"key-chain": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication key-chain for level-1 PDUs; 'level-2': Specify authentication key-chain for level-2 PDUs; ", "format": "enum"}}}]}, "mode-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "mode": {"enum": ["md5"], "type": "string", "description": "'md5': Keyed message digest; ", "format": "enum"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication mode for level-1 PDUs; 'level-2': Specify authentication mode for level-2 PDUs; ", "format": "enum"}}}]}, "send-only-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"send-only": {"default": 0, "type": "number", "description": "Authentication send-only", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication send-only for level-1 PDUs; 'level-2': Specify authentication send-only for level-2 PDUs; ", "format": "enum"}}}]}}}, "wide-metric-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "wide-metric": {"description": "Configure the wide metric for interface", "format": "number", "default": 10, "maximum": 16777214, "minimum": 1, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}}}]}, "hello-interval-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-interval": {"description": "Set Hello interval in seconds (Hello interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}}}]}, "lsp-interval": {"description": "Set LSP transmission interval (LSP transmission interval (milliseconds))", "format": "number", "default": 33, "maximum": 4294967295, "minimum": 1, "type": "number"}, "circuit-type": {"default": "level-1-2", "enum": ["level-1", "level-1-2", "level-2-only"], "type": "string", "description": "'level-1': Level-1 only adjacencies are formed; 'level-1-2': Level-1-2 adjacencies are formed; 'level-2-only': Level-2 only adjacencies are formed; ", "format": "enum"}, "hello-multiplier-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-multiplier": {"description": "Set multiplier for Hello holding time (Hello multiplier value)", "format": "number", "default": 3, "maximum": 100, "minimum": 2, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello multiplier for level-1 IIHs; 'level-2': Specify hello multiplier for level-2 IIHs; ", "format": "enum"}}}]}, "metric-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"metric": {"description": "Configure the metric for interface (Default metric)", "format": "number", "default": 10, "maximum": 63, "minimum": 1, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}}}]}, "hello": {"enum": ["padding"], "type": "string", "description": "'padding': Pad hello packets; ", "format": "enum"}}}, "name": {"description": "Name for the interface", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 32, "type": "string"}, "duplexity": {"description": "'Full': Full; 'Half': Half; 'auto': auto; ", "format": "enum", "default": "auto", "optional": true, "enum": ["Full", "Half", "auto"], "type": "string", "plat-neg-list": ["soft-ax"]}, "icmpv6-rate-limit": {"type": "object", "properties": {"lockup-period-v6": {"description": "Lockup period (second)", "minimum": 1, "type": "number", "maximum": 16383, "format": "number"}, "normal-v6": {"description": "Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "lockup-v6": {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}, "mtu": {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Interface mtu (Interface MTU, default 1500 (min MTU is 1280 for IPv6))", "format": "number", "optional": true, "type": "number"}, "ifnum": {"optional": false, "type": "number", "description": "Ethernet interface number", "format": "interface"}, "monitor-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "monitor-vlan": {"description": "VLAN number", "format": "number", "maximum": 4094, "minimum": 2, "type": "number", "plat-neg-list": ["non-fpga"]}, "monitor": {"description": "'input': Incoming packets; 'output': Outgoing packets; 'both': Both incoming and outgoing packets; ", "partition-visibility": "shared", "format": "enum", "enum": ["input", "output", "both"], "type": "string", "plat-neg-list": ["soft-ax"]}, "mirror-index": {"description": "Mirror index", "format": "number", "maximum": 4, "minimum": 1, "type": "number", "plat-neg-list": ["soft-ax"], "$ref": "/axapi/v3/mirror-port"}}}]}, "lw-4o6": {"type": "object", "properties": {"outside": {"default": 0, "type": "number", "description": "Configure LW-4over6 inside interface", "format": "flag"}, "inside": {"default": 0, "type": "number", "description": "Configure LW-4over6 outside interface", "format": "flag"}}}, "action": {"description": "'enable': Enable; 'disable': Disable; ", "format": "enum", "default": "disable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "icmp-rate-limit": {"type": "object", "properties": {"lockup": {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "lockup-period": {"description": "Lockup period (second)", "minimum": 1, "type": "number", "maximum": 16383, "format": "number"}, "normal": {"description": "Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}, "flow-control": {"description": "Enable 802.3x flow control on full duplex port", "format": "flag", "default": 0, "type": "number", "optional": true, "plat-neg-list": ["soft-ax"]}}}], "type": "array", "$ref": "/axapi/v3/interface/ethernet/{ifnum}"}
    :param lif_list: {"minItems": 1, "items": {"type": "lif"}, "uniqueItems": true, "array": [{"required": ["ifnum"], "properties": {"isis": {"type": "object", "properties": {"priority-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Set priority for Designated Router election (Priority value)", "format": "number", "default": 64, "maximum": 127, "minimum": 0, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify priority for level-1 routing; 'level-2': Specify priority for level-2 routing; ", "format": "enum"}}}]}, "hello-interval-minimal-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"hello-interval-minimal": {"default": 0, "type": "number", "description": "Set Hello holdtime 1 second, interval depends on multiplier", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}}}]}, "mesh-group": {"type": "object", "properties": {"value": {"description": "Mesh group number", "format": "number", "maximum": 4294967295, "minimum": 1, "not": "blocked", "type": "number"}, "blocked": {"default": 0, "not": "value", "type": "number", "description": "Block LSPs on this interface", "format": "flag"}}}, "network": {"enum": ["broadcast", "point-to-point"], "type": "string", "description": "'broadcast': Specify IS-IS broadcast multi-access network; 'point-to-point': Specify IS-IS point-to-point network; ", "format": "enum"}, "bfd-cfg": {"type": "object", "properties": {"disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}}}, "csnp-interval-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Speficy interval for level-1 CSNPs; 'level-2': Specify interval for level-2 CSNPs; ", "format": "enum"}, "optional": true, "csnp-interval": {"description": "Set CSNP interval in seconds (CSNP interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}}}]}, "retransmit-interval": {"description": "Set per-LSP retransmission interval (Interval between retransmissions of the same LSP (seconds))", "format": "number", "default": 5, "maximum": 65535, "minimum": 0, "type": "number"}, "password-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"password": {"minLength": 1, "maxLength": 254, "type": "string", "description": "Configure the authentication password for interface", "format": "string-rlx"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify password for level-1 PDUs; 'level-2': Specify password for level-2 PDUs; ", "format": "enum"}}}]}, "authentication": {"type": "object", "properties": {"key-chain-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"key-chain": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication key-chain for level-1 PDUs; 'level-2': Specify authentication key-chain for level-2 PDUs; ", "format": "enum"}}}]}, "mode-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "mode": {"enum": ["md5"], "type": "string", "description": "'md5': Keyed message digest; ", "format": "enum"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication mode for level-1 PDUs; 'level-2': Specify authentication mode for level-2 PDUs; ", "format": "enum"}}}]}, "send-only-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"send-only": {"default": 0, "type": "number", "description": "Authentication send-only", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication send-only for level-1 PDUs; 'level-2': Specify authentication send-only for level-2 PDUs; ", "format": "enum"}}}]}}}, "wide-metric-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "wide-metric": {"description": "Configure the wide metric for interface", "format": "number", "default": 10, "maximum": 16777214, "minimum": 1, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}}}]}, "hello-interval-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-interval": {"description": "Set Hello interval in seconds (Hello interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}}}]}, "lsp-interval": {"description": "Set LSP transmission interval (LSP transmission interval (milliseconds))", "format": "number", "default": 33, "maximum": 4294967295, "minimum": 1, "type": "number"}, "circuit-type": {"default": "level-1-2", "enum": ["level-1", "level-1-2", "level-2-only"], "type": "string", "description": "'level-1': Level-1 only adjacencies are formed; 'level-1-2': Level-1-2 adjacencies are formed; 'level-2-only': Level-2 only adjacencies are formed; ", "format": "enum"}, "hello-multiplier-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-multiplier": {"description": "Set multiplier for Hello holding time (Hello multiplier value)", "format": "number", "default": 3, "maximum": 100, "minimum": 2, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello multiplier for level-1 IIHs; 'level-2': Specify hello multiplier for level-2 IIHs; ", "format": "enum"}}}]}, "metric-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"metric": {"description": "Configure the metric for interface (Default metric)", "format": "number", "default": 10, "maximum": 63, "minimum": 1, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}}}]}, "hello": {"enum": ["padding"], "type": "string", "description": "'padding': Pad hello packets; ", "format": "enum"}}}, "bfd": {"type": "object", "properties": {"authentication": {"type": "object", "properties": {"encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "password": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Key String", "format": "password"}, "method": {"enum": ["md5", "meticulous-md5", "meticulous-sha1", "sha1", "simple"], "type": "string", "description": "'md5': Keyed MD5; 'meticulous-md5': Meticulous Keyed MD5; 'meticulous-sha1': Meticulous Keyed SHA1; 'sha1': Keyed SHA1; 'simple': Simple Password; ", "format": "enum"}, "key-id": {"description": "Key ID", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}}}, "demand": {"default": 0, "type": "number", "description": "Demand mode", "format": "flag"}, "interval-cfg": {"type": "object", "properties": {"interval": {"description": "Transmit interval between BFD packets (Milliseconds)", "minimum": 48, "type": "number", "maximum": 1000, "format": "number"}, "min-rx": {"description": "Minimum receive interval capability (Milliseconds)", "minimum": 48, "type": "number", "maximum": 1000, "format": "number"}, "multiplier": {"description": "Multiplier value used to compute holddown (value used to multiply the interval)", "minimum": 3, "type": "number", "maximum": 50, "format": "number"}}}, "echo": {"default": 0, "type": "number", "description": "Enable BFD Echo", "format": "flag"}}}, "ip": {"type": "object", "properties": {"generate-membership-query": {"default": 0, "type": "number", "description": "Enable Membership Query", "format": "flag"}, "cache-spoofing-port": {"default": 0, "type": "number", "description": "This interface connects to spoofing cache", "format": "flag"}, "inside": {"default": 0, "type": "number", "description": "Configure interface as inside", "format": "flag"}, "router": {"type": "object", "properties": {"isis": {"type": "object", "properties": {"tag": {"description": "ISO routing area tag", "format": "string", "minLength": 1, "modify-not-allowed": 1, "maxLength": 128, "type": "string"}}}}}, "allow-promiscuous-vip": {"default": 0, "type": "number", "description": "Allow traffic to be associated with promiscuous VIP", "format": "flag"}, "max-resp-time": {"description": "Maximum Response Time (Max Response Time (Default is 100))", "format": "number", "default": 100, "maximum": 255, "minimum": 1, "type": "number"}, "query-interval": {"description": "1 - 255 (Default is 125)", "format": "number", "default": 125, "maximum": 255, "minimum": 1, "type": "number"}, "outside": {"default": 0, "type": "number", "description": "Configure interface as outside", "format": "flag"}, "rip": {"type": "object", "properties": {"receive-cfg": {"type": "object", "properties": {"receive": {"default": 0, "type": "number", "description": "Advertisement reception", "format": "flag"}, "version": {"enum": ["1", "2", "1-2"], "type": "string", "description": "'1': RIP version 1; '2': RIP version 2; '1-2': RIP version 1 & 2; ", "format": "enum"}}}, "receive-packet": {"default": 1, "type": "number", "description": "Enable receiving packet through the specified interface", "format": "flag"}, "split-horizon-cfg": {"type": "object", "properties": {"state": {"default": "poisoned", "enum": ["poisoned", "disable", "enable"], "type": "string", "description": "'poisoned': Perform split horizon with poisoned reverse; 'disable': Disable split horizon; 'enable': Perform split horizon without poisoned reverse; ", "format": "enum"}}}, "authentication": {"type": "object", "properties": {"key-chain": {"type": "object", "properties": {"key-chain": {"type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string-rlx"}}}, "mode": {"type": "object", "properties": {"mode": {"default": "text", "enum": ["md5", "text"], "type": "string", "description": "'md5': Keyed message digest; 'text': Clear text authentication; ", "format": "enum"}}}, "str": {"type": "object", "properties": {"string": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The RIP authentication string", "format": "string-rlx"}}}}}, "send-cfg": {"type": "object", "properties": {"version": {"enum": ["1", "2", "1-compatible", "1-2"], "type": "string", "description": "'1': RIP version 1; '2': RIP version 2; '1-compatible': RIPv1-compatible; '1-2': RIP version 1 & 2; ", "format": "enum"}, "send": {"default": 0, "type": "number", "description": "Advertisement transmission", "format": "flag"}}}, "send-packet": {"default": 1, "type": "number", "description": "Enable sending packets through the specified interface", "format": "flag"}}}, "address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv4-address": {"type": "string", "description": "IP address", "format": "ipv4-address"}, "optional": true, "ipv4-netmask": {"type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}}}]}, "dhcp": {"default": 0, "type": "number", "description": "Use DHCP to configure IP address", "format": "flag"}, "ospf": {"type": "object", "properties": {"ospf-ip-list": {"minItems": 1, "items": {"type": "ospf-ip"}, "uniqueItems": true, "array": [{"required": ["ip-addr"], "properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication-key": {"description": "Authentication password (key) (The OSPF password (key))", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 8, "type": "string"}, "mtu-ignore": {"default": 0, "optional": true, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "priority": {"description": "Router priority", "format": "number", "default": 1, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "value": {"optional": true, "enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use no authentication; ", "format": "enum"}, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication": {"default": 0, "optional": true, "type": "number", "description": "Enable authentication", "format": "flag"}, "cost": {"description": "Interface cost", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "database-filter": {"optional": true, "enum": ["all"], "type": "string", "description": "'all': Filter all LSA; ", "format": "enum"}, "ip-addr": {"optional": false, "type": "string", "description": "Address of interface", "format": "ipv4-address"}, "retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "message-digest-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"md5-value": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}, "message-digest-key": {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}]}, "out": {"default": 0, "optional": true, "type": "number", "description": "Outgoing LSA", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/interface/lif/{ifnum}/ip/ospf/ospf-ip/{ip-addr}"}, "ospf-global": {"type": "object", "properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication-key": {"minLength": 1, "maxLength": 8, "type": "string", "description": "Authentication password (key) (The OSPF password (key))", "format": "string-rlx"}, "network": {"type": "object", "properties": {"broadcast": {"default": 0, "not-list": ["non-broadcast", "point-to-point", "point-to-multipoint"], "type": "number", "description": "Specify OSPF broadcast multi-access network", "format": "flag"}, "point-to-multipoint": {"default": 0, "not-list": ["broadcast", "non-broadcast", "point-to-point"], "type": "number", "description": "Specify OSPF point-to-multipoint network", "format": "flag"}, "non-broadcast": {"default": 0, "not-list": ["broadcast", "point-to-point", "point-to-multipoint"], "type": "number", "description": "Specify OSPF NBMA network", "format": "flag"}, "point-to-point": {"default": 0, "not-list": ["broadcast", "non-broadcast", "point-to-multipoint"], "type": "number", "description": "Specify OSPF point-to-point network", "format": "flag"}, "p2mp-nbma": {"default": 0, "type": "number", "description": "Specify non-broadcast point-to-multipoint network", "format": "flag"}}}, "mtu-ignore": {"default": 0, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "maximum": 65535, "minimum": 1, "type": "number"}, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "disable": {"enum": ["all"], "type": "string", "description": "'all': All functionality; ", "format": "enum"}, "authentication-cfg": {"type": "object", "properties": {"authentication": {"default": 0, "type": "number", "description": "Enable authentication", "format": "flag"}, "value": {"enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use no authentication; ", "format": "enum"}}}, "database-filter-cfg": {"type": "object", "properties": {"database-filter": {"enum": ["all"], "type": "string", "description": "'all': Filter all LSA; ", "format": "enum"}, "out": {"default": 0, "type": "number", "description": "Outgoing LSA", "format": "flag"}}}, "bfd-cfg": {"type": "object", "properties": {"disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}}}, "cost": {"description": "Interface cost", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "mtu": {"description": "OSPF interface MTU (MTU size)", "minimum": 576, "type": "number", "maximum": 65535, "format": "number"}, "message-digest-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"message-digest-key": {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "md5": {"type": "object", "properties": {"md5-value": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}, "encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}}}]}, "priority": {"description": "Router priority", "format": "number", "default": 1, "maximum": 255, "minimum": 0, "type": "number"}}}}}}}, "mtu": {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Interface mtu (Interface MTU, default 1500 (min MTU is 1280 for IPv6))", "format": "number", "optional": true, "type": "number"}, "access-list": {"type": "object", "properties": {"acl-name": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Apply an access list (Named Access List)", "format": "string"}, "acl-id": {"description": "ACL id", "format": "number", "maximum": 199, "$ref-list": ["/axapi/v3/access-list/standard", "/axapi/v3/access-list/extended"], "minimum": 1, "type": "number"}}}, "ifnum": {"description": "Lif interface number", "format": "number", "type": "number", "maximum": 128, "minimum": 1, "optional": false}, "action": {"description": "'enable': Enable; 'disable': Disable; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}}}], "type": "array", "$ref": "/axapi/v3/interface/lif/{ifnum}"}
    :param loopback_list: {"minItems": 1, "items": {"type": "loopback"}, "uniqueItems": true, "array": [{"required": ["ifnum"], "properties": {"ip": {"type": "object", "properties": {"address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv4-address": {"type": "string", "description": "IP address", "format": "ipv4-address"}, "optional": true, "ipv4-netmask": {"type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}}}]}, "ospf": {"type": "object", "properties": {"ospf-ip-list": {"minItems": 1, "items": {"type": "ospf-ip"}, "uniqueItems": true, "array": [{"required": ["ip-addr"], "properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication-key": {"description": "Authentication password (key) (The OSPF password (key))", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 8, "type": "string"}, "mtu-ignore": {"default": 0, "optional": true, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "priority": {"description": "Router priority", "format": "number", "default": 1, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "value": {"optional": true, "enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use no authentication; ", "format": "enum"}, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication": {"default": 0, "optional": true, "type": "number", "description": "Enable authentication", "format": "flag"}, "cost": {"description": "Interface cost", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "database-filter": {"optional": true, "enum": ["all"], "type": "string", "description": "'all': Filter all LSA; ", "format": "enum"}, "ip-addr": {"optional": false, "type": "string", "description": "Address of interface", "format": "ipv4-address"}, "retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "message-digest-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"md5-value": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}, "message-digest-key": {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}]}, "out": {"default": 0, "optional": true, "type": "number", "description": "Outgoing LSA", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/interface/loopback/{ifnum}/ip/ospf/ospf-ip/{ip-addr}"}, "ospf-global": {"type": "object", "properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication-key": {"minLength": 1, "maxLength": 8, "type": "string", "description": "Authentication password (key) (The OSPF password (key))", "format": "string-rlx"}, "mtu-ignore": {"default": 0, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "maximum": 65535, "minimum": 1, "type": "number"}, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "disable": {"enum": ["all"], "type": "string", "description": "'all': All functionality; ", "format": "enum"}, "authentication-cfg": {"type": "object", "properties": {"authentication": {"default": 0, "type": "number", "description": "Enable authentication", "format": "flag"}, "value": {"enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use no authentication; ", "format": "enum"}}}, "database-filter-cfg": {"type": "object", "properties": {"database-filter": {"enum": ["all"], "type": "string", "description": "'all': Filter all LSA; ", "format": "enum"}, "out": {"default": 0, "type": "number", "description": "Outgoing LSA", "format": "flag"}}}, "bfd-cfg": {"type": "object", "properties": {"disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}}}, "cost": {"description": "Interface cost", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "mtu": {"description": "OSPF interface MTU (MTU size)", "minimum": 576, "type": "number", "maximum": 65535, "format": "number"}, "message-digest-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"message-digest-key": {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "md5": {"type": "object", "properties": {"md5-value": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}, "encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}}}]}, "priority": {"description": "Router priority", "format": "number", "default": 1, "maximum": 255, "minimum": 0, "type": "number"}}}}}, "rip": {"type": "object", "properties": {"receive-cfg": {"type": "object", "properties": {"receive": {"default": 0, "type": "number", "description": "Advertisement reception", "format": "flag"}, "version": {"enum": ["1", "2", "1-2"], "type": "string", "description": "'1': RIP version 1; '2': RIP version 2; '1-2': RIP version 1 & 2; ", "format": "enum"}}}, "receive-packet": {"default": 1, "type": "number", "description": "Enable receiving packet through the specified interface", "format": "flag"}, "split-horizon-cfg": {"type": "object", "properties": {"state": {"default": "poisoned", "enum": ["poisoned", "disable", "enable"], "type": "string", "description": "'poisoned': Perform split horizon with poisoned reverse; 'disable': Disable split horizon; 'enable': Perform split horizon without poisoned reverse; ", "format": "enum"}}}, "authentication": {"type": "object", "properties": {"key-chain": {"type": "object", "properties": {"key-chain": {"type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string-rlx"}}}, "mode": {"type": "object", "properties": {"mode": {"default": "text", "enum": ["md5", "text"], "type": "string", "description": "'md5': Keyed message digest; 'text': Clear text authentication; ", "format": "enum"}}}, "str": {"type": "object", "properties": {"string": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The RIP authentication string", "format": "string-rlx"}}}}}, "send-cfg": {"type": "object", "properties": {"version": {"enum": ["1", "2", "1-compatible", "1-2"], "type": "string", "description": "'1': RIP version 1; '2': RIP version 2; '1-compatible': RIPv1-compatible; '1-2': RIP version 1 & 2; ", "format": "enum"}, "send": {"default": 0, "type": "number", "description": "Advertisement transmission", "format": "flag"}}}, "send-packet": {"default": 1, "type": "number", "description": "Enable sending packets through the specified interface", "format": "flag"}}}, "router": {"type": "object", "properties": {"isis": {"type": "object", "properties": {"tag": {"description": "ISO routing area tag", "format": "string", "minLength": 1, "modify-not-allowed": 1, "maxLength": 128, "type": "string"}}}}}}}, "ifnum": {"description": "Loopback interface number", "format": "number", "type": "number", "maximum": 10, "minimum": 0, "optional": false}, "ipv6": {"type": "object", "properties": {"address-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"link-local": {"default": 0, "type": "number", "description": "Configure an IPv6 link local address", "format": "flag"}, "anycast": {"default": 0, "type": "number", "description": "Configure an IPv6 anycast address", "format": "flag"}, "ipv6-addr": {"type": "string", "description": "Set the IPv6 address of an interface", "format": "ipv6-address-plen"}, "optional": true}}]}, "ipv6-enable": {"default": 0, "type": "number", "description": "Enable IPv6 processing", "format": "flag"}, "ospf": {"type": "object", "properties": {"bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "cost-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cost": {"description": "Interface cost", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "hello-interval-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "priority-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Router priority", "format": "number", "default": 1, "maximum": 255, "minimum": 0, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "mtu-ignore-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"mtu-ignore": {"default": 0, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "retransmit-interval-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "maximum": 65535, "minimum": 1, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "transmit-delay-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}, "dead-interval-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "maximum": 65535, "minimum": 1, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}}}, "rip": {"type": "object", "properties": {"split-horizon-cfg": {"type": "object", "properties": {"state": {"default": "poisoned", "enum": ["poisoned", "disable", "enable"], "type": "string", "description": "'poisoned': Perform split horizon with poisoned reverse; 'disable': Disable split horizon; 'enable': Perform split horizon without poisoned reverse; ", "format": "enum"}}}}}, "router": {"type": "object", "properties": {"ripng": {"type": "object", "properties": {"rip": {"default": 0, "type": "number", "description": "RIP Routing for IPv6", "format": "flag"}}}, "ospf": {"type": "object", "properties": {"area-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"area-id-addr": {"type": "string", "description": "OSPF area ID in IP address format", "format": "ipv4-address"}, "tag": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Set the OSPFv3 process tag", "format": "string"}, "optional": true, "instance-id": {"description": "Set the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}, "area-id-num": {"description": "OSPF area ID as a decimal value", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}}}]}}}, "isis": {"type": "object", "properties": {"tag": {"description": "ISO routing area tag", "format": "string", "minLength": 1, "modify-not-allowed": 1, "maxLength": 128, "type": "string"}}}}}}}, "isis": {"type": "object", "properties": {"priority-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Set priority for Designated Router election (Priority value)", "format": "number", "default": 64, "maximum": 127, "minimum": 0, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify priority for level-1 routing; 'level-2': Specify priority for level-2 routing; ", "format": "enum"}}}]}, "hello-interval-minimal-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"hello-interval-minimal": {"default": 0, "type": "number", "description": "Set Hello holdtime 1 second, interval depends on multiplier", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}}}]}, "mesh-group": {"type": "object", "properties": {"value": {"description": "Mesh group number", "format": "number", "maximum": 4294967295, "minimum": 1, "not": "blocked", "type": "number"}, "blocked": {"default": 0, "not": "value", "type": "number", "description": "Block LSPs on this interface", "format": "flag"}}}, "bfd-cfg": {"type": "object", "properties": {"disable": {"default": 0, "type": "number", "description": "Disable BFD", "format": "flag"}, "bfd": {"default": 0, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}}}, "csnp-interval-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Speficy interval for level-1 CSNPs; 'level-2': Specify interval for level-2 CSNPs; ", "format": "enum"}, "optional": true, "csnp-interval": {"description": "Set CSNP interval in seconds (CSNP interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}}}]}, "retransmit-interval": {"description": "Set per-LSP retransmission interval (Interval between retransmissions of the same LSP (seconds))", "format": "number", "default": 5, "maximum": 65535, "minimum": 0, "type": "number"}, "password-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"password": {"minLength": 1, "maxLength": 254, "type": "string", "description": "Configure the authentication password for interface", "format": "string-rlx"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify password for level-1 PDUs; 'level-2': Specify password for level-2 PDUs; ", "format": "enum"}}}]}, "authentication": {"type": "object", "properties": {"key-chain-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"key-chain": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication key-chain for level-1 PDUs; 'level-2': Specify authentication key-chain for level-2 PDUs; ", "format": "enum"}}}]}, "mode-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "mode": {"enum": ["md5"], "type": "string", "description": "'md5': Keyed message digest; ", "format": "enum"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication mode for level-1 PDUs; 'level-2': Specify authentication mode for level-2 PDUs; ", "format": "enum"}}}]}, "send-only-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"send-only": {"default": 0, "type": "number", "description": "Authentication send-only", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication send-only for level-1 PDUs; 'level-2': Specify authentication send-only for level-2 PDUs; ", "format": "enum"}}}]}}}, "wide-metric-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "wide-metric": {"description": "Configure the wide metric for interface", "format": "number", "default": 10, "maximum": 16777214, "minimum": 1, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}}}]}, "hello-interval-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-interval": {"description": "Set Hello interval in seconds (Hello interval value)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello-interval for level-1 IIHs; 'level-2': Specify hello-interval for level-2 IIHs; ", "format": "enum"}}}]}, "lsp-interval": {"description": "Set LSP transmission interval (LSP transmission interval (milliseconds))", "format": "number", "default": 33, "maximum": 4294967295, "minimum": 1, "type": "number"}, "circuit-type": {"default": "level-1-2", "enum": ["level-1", "level-1-2", "level-2-only"], "type": "string", "description": "'level-1': Level-1 only adjacencies are formed; 'level-1-2': Level-1-2 adjacencies are formed; 'level-2-only': Level-2 only adjacencies are formed; ", "format": "enum"}, "hello-multiplier-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-multiplier": {"description": "Set multiplier for Hello holding time (Hello multiplier value)", "format": "number", "default": 3, "maximum": 100, "minimum": 2, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify hello multiplier for level-1 IIHs; 'level-2': Specify hello multiplier for level-2 IIHs; ", "format": "enum"}}}]}, "metric-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"metric": {"description": "Configure the metric for interface (Default metric)", "format": "number", "default": 10, "maximum": 63, "minimum": 1, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Apply metric to level-1 links; 'level-2': Apply metric to level-2 links; ", "format": "enum"}}}]}, "hello": {"enum": ["padding"], "type": "string", "description": "'padding': Pad hello packets; ", "format": "enum"}}}, "snmp-server": {"type": "object", "properties": {"trap-source": {"default": 0, "type": "number", "description": "The trap source", "format": "flag"}}}}}], "type": "array", "$ref": "/axapi/v3/interface/loopback/{ifnum}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "interface"
        self.a10_url="/axapi/v3/interface"
        self.DeviceProxy = ""
        self.tunnel_list = []
        self.management = {}
        self.trunk_list = []
        self.ve_list = []
        self.ethernet_list = []
        self.lif_list = []
        self.loopback_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


